@@ -1,2 +1,2 @@
-set.seed(0)
-accrual.data<-round(rexp(300,1/(365.25*3/300)))
\ No newline at end of file
+# set.seed(0)
+accrual.data<-round(rexp(300,1/(365.25*3/300)))
